@@ -231,12 +231,12 @@ class App(RedisMixin, LoggingMixin, RollbarMixin):
             try:
                 module = module_type(self.state)
             except Exception:
-                raise exceptions.Misconfigured("Module not able to initialize {0}".format(module_type))
+                raise exceptions.Misconfigured("Module {0} not able to initialize for asset_id {1}".format(module_type, self.asset_id))
 
             try:
                 module.run(self.event)
-            except Exception:
-                self.track_error("Error running module {0} for asset:{1}".format(module_type, self.asset_id), "error")
+            except Exception as ex:
+                self.rollbar.report_exc_info(ex)
 
         last_processed_timestamp = self.event[-1].get('timestamp')
         self.state['last_processed_timestamp'] = last_processed_timestamp
