@@ -41,7 +41,7 @@ class RedisMixin(object):
 
         redis_state_keys = r.keys(pattern)
         for key in redis_state_keys:
-            out = r.delete(key)
+            r.delete(key)
 
 
 class LoggingMixin(object):
